Package: crystract
Type: Package
Title: Crystallographic Information File (CIF) Data Processing Tools
Version: 1.0.1
Authors@R: c(person(given = "Don", 
                  family = "Ngo", 
                  email = "dngo@carnegiescience.edu", 
                  role = c("aut", "cre"),
                  comment = c(ORCID = "0009-0001-2779-2146")),
           person(given = "Anirudh", 
                  family = "Prabhu", 
                  email = "aprabhu@carnegiescience.edu", 
                  role = c("aut"),
                  comment = c(ORCID = "0000-0002-9921-6084")),
           person(given = "Julia-Maria", 
                  family = "Hubner", 
                  email = "julia-maria.huebner@tu-dresden.de",
                  role = c("aut"),
                  comment = c(ORCID = "0000-0003-2048-6629"))
                  )
Maintainer: Don Ngo <dngo@carnegiescience.edu>
Description: Provides a suite of functions to parse Crystallographic Information
    Files (.cif), extracting essential data such as chemical formulas, unit cell
    parameters, atomic coordinates, and symmetry operations. It also includes
    tools to calculate interatomic distances, identify bonded pairs using various
    algorithms (minimum_distance, brunner_nn_reciprocal, econ_nn, crystal_nn), determine nearest
    neighbor counts, and calculate bond angles. The package is designed to
    facilitate the preparation of crystallographic data for further analysis,
    including machine learning applications in materials science.
    Methods are described in:
    Brunner (1977) <doi:10.1107/S0567739477000461>;
    Hoppe (1979) <doi:10.1524/zkri.1979.150.14.23>;
    O'Keeffe (1979) <doi:10.1107/S0567739479001765>;
    Shannon (1976) <doi:10.1107/S0567739476001551>;
    Pan et al. (2021) <doi:10.1021/acs.inorgchem.0c02996>;
    Pauling (1960, ISBN:978-0801403330).
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 3.5.0)
Imports: data.table, dplyr, stringr, future, future.apply, geometry
Suggests: DT, ggplot2, htmlwidgets, knitr, plotly, rmarkdown, testthat
        (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
LazyData: true
URL: https://prabhulab.github.io/ml-crystals/
NeedsCompilation: no
Packaged: 2026-05-28 17:41:44 UTC; donngo
Author: Don Ngo [aut, cre] (ORCID: <https://orcid.org/0009-0001-2779-2146>),
  Anirudh Prabhu [aut] (ORCID: <https://orcid.org/0000-0002-9921-6084>),
  Julia-Maria Hubner [aut] (ORCID:
    <https://orcid.org/0000-0003-2048-6629>)
Repository: CRAN
Date/Publication: 2026-05-28 18:30:02 UTC
