# Generated by roxygen2: do not edit by hand

export(aggregate_batch_results)
export(analyze_cif_files)
export(analyze_single_cif)
export(apply_symmetry_operations)
export(brunner_nn_reciprocal)
export(calculate_angles)
export(calculate_distances)
export(calculate_expansion_factors)
export(calculate_neighbor_counts)
export(calculate_weighted_average_network_distance)
export(calculate_weighted_neighbor_counts)
export(covalent_radii)
export(crystal_nn)
export(econ_nn)
export(expand_transformed_coords)
export(export_analysis_to_csv)
export(extract_atomic_coordinates)
export(extract_chemical_formula)
export(extract_database_code)
export(extract_space_group_name)
export(extract_space_group_number)
export(extract_structure_type)
export(extract_symmetry_operations)
export(extract_unit_cell_metrics)
export(filter_atoms_by_symbol)
export(filter_by_elements)
export(filter_by_wyckoff_symbol)
export(filter_ghost_distances)
export(merge_sites_pbc)
export(minimum_distance)
export(propagate_angle_error)
export(propagate_distance_error)
export(read_cif_files)
export(set_radii_data)
export(voronoi_nn)
importFrom(data.table,":=")
importFrom(data.table,.N)
importFrom(data.table,.SD)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,fread)
importFrom(data.table,rbindlist)
importFrom(data.table,set)
importFrom(data.table,setkey)
importFrom(data.table,setnames)
importFrom(dplyr,distinct)
importFrom(geometry,delaunayn)
importFrom(stats,as.dist)
importFrom(stats,cutree)
importFrom(stats,hclust)
importFrom(stats,na.omit)
importFrom(stringr,str_match)
importFrom(stringr,str_split_fixed)
importFrom(utils,combn)
importFrom(utils,globalVariables)
