utils::globalVariables(
  c(
    # Core data.table symbols
    ".",
    ".N",
    ".I",

    # Column names used across multiple files
    "Angle",
    "AngleError",
    "Area",
    "Atom1",
    "Atom2",
    "BondStrength",
    "CentralAtom",
    "DeltaX",
    "DeltaY",
    "DeltaZ",
    "Distance",
    "DistanceError",
    "Element",
    "Element1",
    "Element2",
    "file_name",
    "FullWyckoff",
    "Label",
    "Neighbor1",
    "Neighbor2",
    "NeighborCount",
    "Occupancy",
    "Occupancy2",
    "Parent1",
    "Parent2",
    "ParentLabel",
    "Radius",
    "Radius1",
    "Radius2",
    "SolidAngle",
    "Symbol",
    "Type",
    "V1",
    "Weight",
    "WyckoffMultiplicity",
    "WyckoffSymbol",
    "x",
    "y",
    "z",
    "x_a",
    "x_error",
    "y_b",
    "y_error",
    "z_c",
    "z_error",

    # Variables for bonding algorithms
    "dcut",
    "dmin",
    "CutoffLow",
    "CutoffHigh",
    "Target",
    "R1",
    "R2",
    "RecipGap",
    "IsMaxGap",
    "CutoffDist",
    "MinDist",
    "FictiveR",
    "MEFIR",
    "Sym1",
    "Sym2",
    "EN1",
    "EN2",
    "RawWeight",
    "ChemMod",
    "MaxW",
    "Diameter",
    "CutLow",
    "CutHigh",
    "DistMod",
    "MaxSA",
    "Coordination",
    "OxidationState",
    "Diff",
    "Atom1_Index",
    "Atom2_Index",
    "Atom1_Label",
    "Atom2_Label",
    "Tx",
    "Ty",
    "Tz",
    "OS1",
    "i.OxidationState",
    "OS2",
    "i.MEFIR",
    "MaxScore",
    "RadiusSum",
    "RawScore",

    # Variables for calculate_angles
    "cos_theta",
    "cx",
    "cy",
    "cz",
    "dot_product",
    "i.x_a",
    "i.y_b",
    "i.z_c",
    "mag1",
    "mag2",
    "mag_sq1",
    "mag_sq2",
    "n1x",
    "n1y",
    "n1z",
    "n2x",
    "n2y",
    "n2z",
    "Neighbor1_sorted",
    "Neighbor2_sorted",
    "xf1",
    "xf2",
    "yf1",
    "yf2",
    "zf1",
    "zf2",

    # Variables for error propagation
    "a_vx",
    "a_vy",
    "a_vz",
    "b_vx",
    "b_vy",
    "b_vz",
    "C_val",
    "dx",
    "dy",
    "dz",
    "i.s_xc_sq",
    "i.s_yc_sq",
    "i.s_zc_sq",
    "i.xc",
    "i.yc",
    "i.zc",
    "mag_a",
    "mag_b",
    "Original_Atom2",
    "p_C_xc1",
    "p_C_xc2",
    "p_C_xc3",
    "p_C_yc1",
    "p_C_yc2",
    "p_C_yc3",
    "p_C_zc1",
    "p_C_zc2",
    "p_C_zc3",
    "p_xc_a",
    "p_xc_alpha",
    "p_xc_b",
    "p_xc_beta",
    "p_xc_c",
    "p_xc_gamma",
    "p_xc_xf",
    "p_xc_yf",
    "p_xc_zf",
    "p_yc_a",
    "p_yc_alpha",
    "p_yc_b",
    "p_yc_beta",
    "p_yc_c",
    "p_yc_gamma",
    "p_yc_xf",
    "p_yc_yf",
    "p_yc_zf",
    "p_zc_a",
    "p_zc_alpha",
    "p_zc_b",
    "p_zc_beta",
    "p_zc_c",
    "p_zc_gamma",
    "p_zc_xf",
    "p_zc_yf",
    "p_zc_zf",
    "pd_a",
    "pd_alpha",
    "pd_b",
    "pd_beta",
    "pd_c",
    "pd_gamma",
    "pd_xf1",
    "pd_xf2",
    "pd_yf1",
    "pd_yf2",
    "pd_zf1",
    "pd_zf2",
    "Parent_C",
    "Parent_N1",
    "Parent_N2",
    "s_C_sq",
    "s_theta_sq",
    "s_xc1_sq",
    "s_xc2_sq",
    "s_xc3_sq",
    "s_xc_sq",
    "s_yc1_sq",
    "s_yc2_sq",
    "s_yc3_sq",
    "s_yc_sq",
    "s_zc1_sq",
    "s_zc2_sq",
    "s_zc3_sq",
    "s_zc_sq",
    "s_xf",
    "s_xf1",
    "s_xf2",
    "s_yf",
    "s_yf1",
    "s_yf2",
    "s_zf",
    "s_zf1",
    "s_zf2",
    "term_common",
    "variance",
    "xc",
    "xc1",
    "xc2",
    "xc3",
    "yc",
    "yc1",
    "yc2",
    "yc3",
    "zc",
    "zc1",
    "zc2",
    "zc3",

    # Variables for post-processing and analysis
    "..meta_col_names",
    "..required_metrics",
    "expected_dist",
    "lower_bound",
    "n",
    "sum_d",
    "upper_bound",
    "null",
    "..valid_cols",

    # Voronoi NN specific
    "idx",
    "idx1",
    "idx2",
    "temp",
    "x1",
    "x2",
    "y1",
    "y2",
    "z1",
    "z2",
    "X",
    "center_coords",
    "my_tets",
    "neighbor_indices",
    "prim_label",

    # CrystalNN specific
    "atomic_rads",

    # Merge Sites
    "ClusterID",
    "N",

    # Unit cell metrics used in apply_symmetry_operations
    "unit_cell_metrics",

    # Internal
    "pauling_en",
    "shannon_radii",
    "NeighborSite",
    "get_default_radius",
    "get_ionic_radius",
    "m_i",
    "OccupancyError",
    "ThermalParam",
    "TypeSymbol",
    "gx",
    "gy",
    "gz"

  )
)
