% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extract_cif_data.R
\name{extract_atomic_coordinates}
\alias{extract_atomic_coordinates}
\title{Extract Atomic Coordinates}
\usage{
extract_atomic_coordinates(cif_content, chemical_formula = NA)
}
\arguments{
\item{cif_content}{A \code{data.table} containing the lines of a CIF file.}

\item{chemical_formula}{The chemical formula string for validation.}
}
\value{
A \code{data.table} with atomic coordinate data, or \code{NULL} if not found.
}
\description{
Parses atomic site info, including labels, fractional coordinates,
occupancies, oxidation states, and thermal parameters. It includes logic
to extract oxidation states from both site tags and type loops.
}
\examples{
cif_path <- system.file("extdata", "1590946.cif", package = "crystract")
if (file.exists(cif_path)) {
  cif_content <- read_cif_files(cif_path)[[1]]
  extract_atomic_coordinates(cif_content)
}
}
\seealso{
Other extractors: 
\code{\link{extract_chemical_formula}()},
\code{\link{extract_database_code}()},
\code{\link{extract_space_group_name}()},
\code{\link{extract_space_group_number}()},
\code{\link{extract_structure_type}()},
\code{\link{extract_symmetry_operations}()},
\code{\link{extract_unit_cell_metrics}()}
}
\concept{extractors}
